@@ -1,6 +1,8 @@
 import datetime
+import enum
 import json
 import re
+from contextlib import suppress
 from enum import Enum
 from typing import Union
 
@@ -9,13 +11,12 @@ from google.protobuf import timestamp_pb2
 from google.cloud import pubsub_v1
 from google.cloud import tasks_v2
 from google.cloud import error_reporting
-from expressmoney import status
 
 report = error_reporting.Client()
 
 
-class Status(Enum):
-    """ViewFlow status"""
+class ViewFlowStatus(Enum):
+    """Process result statuses for ViewFlow framework"""
     EMPTY = 'EMPTY'
     NEW = 'NEW'
     IN_PROCESS = 'INPR'
@@ -26,6 +27,97 @@ class Status(Enum):
     RETRY = 'RETRY'
 
 
+@enum.unique
+class HttpStatus(enum.IntEnum):
+    """
+    Descriptive HTTP status codes, for code readability.
+
+    See RFC 2616 - https://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html
+    And RFC 6585 - https://tools.ietf.org/html/rfc6585
+    And RFC 4918 - https://tools.ietf.org/html/rfc4918
+    """
+    HTTP_100_CONTINUE = 100
+    HTTP_101_SWITCHING_PROTOCOLS = 101
+    HTTP_200_OK = 200
+    HTTP_201_CREATED = 201
+    HTTP_202_ACCEPTED = 202
+    HTTP_203_NON_AUTHORITATIVE_INFORMATION = 203
+    HTTP_204_NO_CONTENT = 204
+    HTTP_205_RESET_CONTENT = 205
+    HTTP_206_PARTIAL_CONTENT = 206
+    HTTP_207_MULTI_STATUS = 207
+    HTTP_208_ALREADY_REPORTED = 208
+    HTTP_226_IM_USED = 226
+    HTTP_300_MULTIPLE_CHOICES = 300
+    HTTP_301_MOVED_PERMANENTLY = 301
+    HTTP_302_FOUND = 302
+    HTTP_303_SEE_OTHER = 303
+    HTTP_304_NOT_MODIFIED = 304
+    HTTP_305_USE_PROXY = 305
+    HTTP_306_RESERVED = 306
+    HTTP_307_TEMPORARY_REDIRECT = 307
+    HTTP_308_PERMANENT_REDIRECT = 308
+    HTTP_400_BAD_REQUEST = 400
+    HTTP_401_UNAUTHORIZED = 401
+    HTTP_402_PAYMENT_REQUIRED = 402
+    HTTP_403_FORBIDDEN = 403
+    HTTP_404_NOT_FOUND = 404
+    HTTP_405_METHOD_NOT_ALLOWED = 405
+    HTTP_406_NOT_ACCEPTABLE = 406
+    HTTP_407_PROXY_AUTHENTICATION_REQUIRED = 407
+    HTTP_408_REQUEST_TIMEOUT = 408
+    HTTP_409_CONFLICT = 409
+    HTTP_410_GONE = 410
+    HTTP_411_LENGTH_REQUIRED = 411
+    HTTP_412_PRECONDITION_FAILED = 412
+    HTTP_413_REQUEST_ENTITY_TOO_LARGE = 413
+    HTTP_414_REQUEST_URI_TOO_LONG = 414
+    HTTP_415_UNSUPPORTED_MEDIA_TYPE = 415
+    HTTP_416_REQUESTED_RANGE_NOT_SATISFIABLE = 416
+    HTTP_417_EXPECTATION_FAILED = 417
+    HTTP_418_IM_A_TEAPOT = 418
+    HTTP_422_UNPROCESSABLE_ENTITY = 422
+    HTTP_423_LOCKED = 423
+    HTTP_424_FAILED_DEPENDENCY = 424
+    HTTP_426_UPGRADE_REQUIRED = 426
+    HTTP_428_PRECONDITION_REQUIRED = 428
+    HTTP_429_TOO_MANY_REQUESTS = 429
+    HTTP_431_REQUEST_HEADER_FIELDS_TOO_LARGE = 431
+    HTTP_451_UNAVAILABLE_FOR_LEGAL_REASONS = 451
+    HTTP_500_INTERNAL_SERVER_ERROR = 500
+    HTTP_501_NOT_IMPLEMENTED = 501
+    HTTP_502_BAD_GATEWAY = 502
+    HTTP_503_SERVICE_UNAVAILABLE = 503
+    HTTP_504_GATEWAY_TIMEOUT = 504
+    HTTP_505_HTTP_VERSION_NOT_SUPPORTED = 505
+    HTTP_506_VARIANT_ALSO_NEGOTIATES = 506
+    HTTP_507_INSUFFICIENT_STORAGE = 507
+    HTTP_508_LOOP_DETECTED = 508
+    HTTP_509_BANDWIDTH_LIMIT_EXCEEDED = 509
+    HTTP_510_NOT_EXTENDED = 510
+    HTTP_511_NETWORK_AUTHENTICATION_REQUIRED = 511
+
+    @staticmethod
+    def is_informational(code):
+        return 100 <= code <= 199
+
+    @staticmethod
+    def is_success(code):
+        return 200 <= code <= 299
+
+    @staticmethod
+    def is_redirect(code):
+        return 300 <= code <= 399
+
+    @staticmethod
+    def is_client_error(code):
+        return 400 <= code <= 499
+
+    @staticmethod
+    def is_server_error(code):
+        return 500 <= code <= 599
+
+
 def fix_flow_signal(func):
     def _wrapper_fix_signal(self, **kwargs):
         kwargs.update({'self': self})
@@ -195,28 +287,17 @@ class Request:
 
     def get(self):
         response = requests.get(self._uri, headers=self._headers, timeout=self._timeout)
-        self._handle_exception(response)
         return response
 
     def put(self, payload=None):
         payload = {} if payload is None else payload
         response = requests.put(self._uri, json=payload, headers=self._headers, timeout=self._timeout)
-        self._handle_exception(response)
         return response
 
     def post(self, payload: dict):
         response = requests.post(self._uri, json=payload, headers=self._headers, timeout=self._timeout)
-        self._handle_exception(response)
         return response
 
-    @staticmethod
-    def _handle_exception(response):
-        if not any((status.is_success(response.status_code), status.is_client_error(response.status_code))):
-            try:
-                raise Exception(f'{response.status_code}:{response.url}:{response.json()}')
-            except Exception:
-                raise Exception(f'{response.status_code}:{response.url}:{response.text}')
-
     def post_file(self, file, file_name: str, type_: int = 1, is_public=False):
         """
         Save file in Google Storage
@@ -246,14 +327,18 @@ class Request:
             'is_public': is_public,
 
         }
+
+        with suppress(Exception):
+            file = getattr(file, 'file')
+
         response = requests.post(
             url=self._uri,
             data=data,
-            files={"file": (new_file_name, file.file)},
+            files={"file": (new_file_name, file)},
             headers=self._headers,
             timeout=self._timeout
         )
-        if not any((status.is_success(response.status_code), status.is_client_error(response.status_code))):
+        if not any((HttpStatus.is_success(response.status_code), HttpStatus.is_client_error(response.status_code))):
             try:
                 raise Exception(f'{response.status_code}:{response.url}:{response.json()}')
             except Exception:
